<?php

namespace Drupal\css_js_performance_improvement\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\css_js_performance_improvement\Service\DefaultService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class DeleteCSS.
 */
final class DeleteCSS extends FormBase {

  /**
   * @var FileSystemInterface $fileSystem
   */
  protected $fileSystem;

  /**
   * @var DefaultService $defaultService
   */
   protected $defaultService;
 
   /**
    * @var MessengerInterface $messenger
    */
   protected $messenger;

  /**
   * {@inheritdoc}
   */
   public function __construct(
	   FileSystemInterface $file_system, 
	   DefaultService $default_service, 
	   MessengerInterface $messenger
   ) {
    $this->fileSystem = $file_system;
    $this->defaultService = $default_service;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('file_system'),
      $container->get('css_js_performance_improvement.default'),
      $container->get('messenger'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_css';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['warning'] = [
      '#type' => 'item',
      '#description' => $this->t('
        <div role="contentinfo" aria-label="Warning message" class="messages messages--warning">
          <h2 class="visually-hidden">Warning message</h2>
          By clicking on the button you will delete the CSS/JS files generated by this module, so it will be regenerated at the first opportunity.<br>
          <b>If you know what you are doing, go on without fear! Furthermore, Drupal cache will be cleared.</b>
        </div>'),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete all CSS and JS files'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if($this->defaultService->remove_all_folder_files($this->fileSystem->realpath('public://public/css_js_performance_improvement/css/*')) &&
       $this->defaultService->remove_all_folder_files($this->fileSystem->realpath('public://public/css_js_performance_improvement/js/*'))) {
      drupal_flush_all_caches();
      $this->messenger->addMessage($this->t('Operazione di cancellazione eseguita con successo!'));
    }
  }

}
